@@ -2,12 +2,17 @@
 
 import inspect
 import logging
+import re
 import sys
 import six
 
 from django.core.files import File
 from django.db.models import Field
-from django.utils.importlib import import_module
+
+try:
+    from importlib import import_module
+except ImportError:
+    from django.utils.importlib import import_module
 
 from django_dynamic_fixture.django_helper import get_related_model, \
     field_has_choices, field_has_default_value, get_fields_from_model, \
@@ -60,28 +65,49 @@ class PendingField(Exception):
     "Internal exception to control pending fields when using Copier."
 
 
+class CantOverrideLesson(Exception):
+    "Override a lesson is an anti-pattern and will turn your test suite very hard to understand."
+
+
+def _validate_model(model_class):
+    if not is_model_class(model_class):
+        raise InvalidReceiverError(model_class, 'Invalid model')
+
+
+def _validate_function(model_class, callback_function):
+    if not inspect.isfunction(callback_function) or not callback_function:
+        raise InvalidReceiverError(model_class, 'Invalid function')
+    if callback_function:
+        if six.PY3:
+            args = len(inspect.getfullargspec(callback_function).args)
+        else:
+            args = len(inspect.getargspec(callback_function).args)
+    if args != 1:
+        raise InvalidReceiverError(model_class, 'Invalid number of function arguments')
+
+
 def set_pre_save_receiver(model_class, callback_function):
-    """
+    '''
     :model_class: a model_class can have only one receiver. Do not complicate yourself.
     :callback_function must be a function that receive the instance as unique parameter.
-    """
-    if not is_model_class(model_class) or not inspect.isfunction(callback_function) or len(inspect.getargspec(callback_function).args) != 1:
-        raise InvalidReceiverError(model_class)
+    '''
+    _validate_model(model_class)
+    _validate_function(model_class, callback_function)
     _PRE_SAVE[model_class] = callback_function
 
 
 def set_post_save_receiver(model_class, callback_function):
-    """
+    '''
     :model_class: a model_class can have only one receiver. Do not complicate yourself.
     :callback_function must be a function that receive the instance as unique parameter.
-    """
-    if not is_model_class(model_class) or not inspect.isfunction(callback_function) or len(inspect.getargspec(callback_function).args) != 1:
-        raise(InvalidReceiverError(model_class))
+    '''
+    _validate_model(model_class)
+    _validate_function(model_class, callback_function)
     _POST_SAVE[model_class] = callback_function
 
 
 class DataFixture(object):
-    """
+    '''
     Responsibility: return a valid data for a Django Field, according to its type, model class, constraints etc.
 
     You must create a separated method to generate data for an specific field. For a field called 'MyField',
@@ -91,7 +117,7 @@ class DataFixture(object):
 
     :field: Field object.
     :key: string that represents a unique name for a Field, considering app, model and field names.
-    """
+    '''
     def __init__(self):
         self.plugins = {}
 
@@ -113,7 +139,7 @@ class DataFixture(object):
                 return None
 
     def generate_data(self, field):
-        "Get a unique and valid data for the field."
+        '''Get a unique and valid data for the field.'''
         field_fullname = field.__module__ + "." + field.__class__.__name__
         fixture = self.plugins.get(field_fullname, {})
         if type(fixture) == dict:
@@ -129,21 +155,21 @@ class DataFixture(object):
             if field.null:
                 data = None # a workaround for versatility
             else:
-                raise(UnsupportedFieldError(get_unique_field_name(field)))
+                raise(UnsupportedFieldError(get_unique_field_name(field) + ' (%s)' % (field_fullname)))
         return data
 
 
 class Copier(object):
-    """
+    '''
     Wrapper of an expression in the format 'field' or 'field.field' or 'field.field.field' etc
     This expression will be interpreted to copy the value of the specified field to the current field.
     Example of usage: G(MyModel, x=C('y.z')) => the value 'z' of field 'y' will be copied to field 'x'.
-    """
+    '''
     def __init__(self, expression):
         self.expression = expression
 
     def __str__(self):
-        return u"C('%s')" % self.expression
+        return "C('%s')" % self.expression
 
     def immediate_field_name(self, instance):
         model_class = instance.__class__
@@ -181,6 +207,8 @@ class DDFLibrary(object):
     def add_configuration(self, model_class, kwargs, name=None):
         if name in [None, True]:
             name = self.DEFAULT_KEY
+        if model_class in self.configs and name in self.configs[model_class]:
+            raise CantOverrideLesson('A lesson {} has already been saved for the model {}'.format(name, model_class))
         model_class_config = self.configs.setdefault(model_class, {})
         model_class_config[name] = kwargs
 
@@ -190,52 +218,51 @@ class DDFLibrary(object):
         # copy is important because this dict will be updated every time in the algorithm.
         config = self.configs.get(model_class, {})
         if name != self.DEFAULT_KEY and name not in config.keys():
-            raise InvalidConfigurationError('There is no shelved configuration for model %s with the name "%s"' % (get_unique_model_name(model_class), name))
+            raise InvalidConfigurationError('There is no lesson for model %s with the name "%s"' % (get_unique_model_name(model_class), name))
         return config.get(name, {}).copy() # default configuration never raises an error
 
     def clear(self):
-        "Remove all shelved configurations of the library."
+        '''Remove all lessons of the library. Util for the DDF tests.'''
         self.configs = {}
 
     def clear_configuration(self, model_class):
-        "Remove from the library an specific configuration of a model."
+        '''Remove from the library an specific configuration of a model.'''
         if model_class in self.configs.keys():
             del self.configs[model_class]
 
 
 class DynamicFixture(object):
-    """
+    '''
     Responsibility: create a valid model instance according to the given configuration.
-    """
+    '''
 
-    _DDF_CONFIGS = ['fill_nullable_fields', 'ignore_fields', 'data_fixture', 'number_of_laps', 'use_library',
-                    'validate_models', 'validate_args', 'print_errors']
+    _DDF_CONFIGS = ['fill_nullable_fields', 'ignore_fields', 'data_fixture', 'fk_min_depth',
+                    'validate_models', 'print_errors']
 
-    def __init__(self, data_fixture, fill_nullable_fields=True, ignore_fields=[], number_of_laps=1, use_library=False,
-                 validate_models=False, validate_args=False, print_errors=True, model_path=[], debug_mode=False, **kwargs):
-        """
+    def __init__(self, data_fixture, fill_nullable_fields=False, ignore_fields=[], fk_min_depth=0,
+                 validate_models=False, print_errors=True, debug_mode=False, **kwargs):
+        '''
         :data_fixture: algorithm to fill field data.
         :fill_nullable_fields: flag to decide if nullable fields must be filled with data.
         :ignore_fields: list of field names that must not be filled with data.
-        :number_of_laps: number of laps for each cyclic dependency.
-        :use_library: flag to decide if DDF library will be used to load default fixtures.
+        :fk_min_depth: how deep DDF should go to create non-required FKs fields from the main model.
         :validate_models: flag to decide if the model_instance.full_clean() must be called before saving the object.
-        :validate_args: flag to enable field name validation of custom fixtures.
         :print_errors: flag to determine if the model data must be printed to console on errors. For some scripts is interesting to disable it.
-        :model_path: internal variable used to control the cycles of dependencies.
-        """
+        '''
+        from django_dynamic_fixture.global_settings import DDF_IGNORE_FIELDS
+        from django_dynamic_fixture.fixture_algorithms import FixtureFactory
         # custom config of fixtures
-        self.data_fixture = data_fixture
+        self.data_fixture = FixtureFactory.get(data_fixture)
+
         self.fill_nullable_fields = fill_nullable_fields
         self.ignore_fields = ignore_fields
-        self.number_of_laps = number_of_laps
-        self.use_library = use_library
+        # extend ignore_fields with globally declared ignore_fields
+        self.ignore_fields.extend(DDF_IGNORE_FIELDS)
+        self.fk_min_depth = fk_min_depth
         # other ddfs configs
         self.validate_models = validate_models
-        self.validate_args = validate_args
         self.print_errors = print_errors
         # internal logic
-        self.model_path = model_path
         self.pending_fields = []
         self.fields_processed = []
         self.debug_mode = debug_mode
@@ -244,13 +271,13 @@ class DynamicFixture(object):
         self.fields_to_disable_auto_now_add = []
 
     def __str__(self):
-        return u'F(%s)' % (u', '.join(u'%s=%s' % (key, value) for key, value in self.kwargs.items()))
+        return 'F(%s)' % (', '.join(six.text_type('%s=%s') % (key, value) for key, value in self.kwargs.items()))
 
     def __eq__(self, that):
-        return self.kwargs == that.kwargs
+        return isinstance(that, self.__class__) and self.kwargs == that.kwargs
 
     def _get_data_from_custom_dynamic_fixture(self, field, fixture, persist_dependencies):
-        "return data of a Dynamic Fixture: field=F(...)"
+        '''return data of a Dynamic Fixture: field=F(...)'''
         next_model = get_related_model(field)
         if persist_dependencies:
             data = fixture.get(next_model)
@@ -259,7 +286,7 @@ class DynamicFixture(object):
         return data
 
     def _get_data_from_custom_copier(self, instance, field, fixture):
-        "return data of a Copier: field=C(...)"
+        '''return data of a Copier: field=C(...)'''
         field_name = fixture.immediate_field_name(instance)
         if field_name in self.fields_processed:
             data = fixture.eval_expression(instance)
@@ -269,17 +296,17 @@ class DynamicFixture(object):
         return data
 
     def _get_data_from_data_fixture(self, field, fixture):
-        "return data of a Data Fixture: field=DataFixture()"
+        '''return data of a Data Fixture: field=DataFixture()'''
         next_model = get_related_model(field)
         return fixture.generate_data(next_model)
 
     def _get_data_from_a_custom_function(self, field, fixture):
-        "return data of a custom function: field=lambda field: field.name"
+        '''Returns data of a custom function: field=lambda field: field.name'''
         data = fixture(field)
         return data
 
     def _get_data_from_static_data(self, field, fixture):
-        "return date from a static value: field=3"
+        '''return date from a static value: field=3'''
         if hasattr(field, 'auto_now_add') and field.auto_now_add:
             self.fields_to_disable_auto_now_add.append(field)
         if hasattr(field, 'auto_now') and field.auto_now:
@@ -287,7 +314,7 @@ class DynamicFixture(object):
         return fixture
 
     def _process_field_with_customized_fixture(self, instance, field, fixture, persist_dependencies):
-        "Set a custom value to a field."
+        '''Set a custom value to a field.'''
         if isinstance(fixture, DynamicFixture): # DynamicFixture (F)
             data = self._get_data_from_custom_dynamic_fixture(field, fixture, persist_dependencies)
         elif isinstance(fixture, Copier): # Copier (C)
@@ -301,52 +328,63 @@ class DynamicFixture(object):
         return data
 
     def _process_foreign_key(self, model_class, field, persist_dependencies):
-        "Returns auto-generated value for a field ForeignKey or OneToOneField."
+        '''
+        Returns auto-generated value for a field ForeignKey or OneToOneField.
+        '''
         if field_is_a_parent_link(field):
             return None
         next_model = get_related_model(field)
-        occurrences = self.model_path.count(next_model)
-        if occurrences >= self.number_of_laps:
-            data = None
+
+        # 1. Propagate ignored_fields only for self references
+        if model_class == next_model: # self reference
+            ignore_fields = self.ignore_fields
         else:
-            next_model_path = self.model_path[:]
-            next_model_path.append(model_class)
-            if model_class == next_model: # self reference
-                # propagate ignored_fields only for self references
-                ignore_fields = self.ignore_fields
-            else:
-                ignore_fields = []
-            # need a new DynamicFixture to control the cycles and ignored fields.
-            fixture = DynamicFixture(data_fixture=self.data_fixture,
-                                     fill_nullable_fields=self.fill_nullable_fields,
-                                     ignore_fields=ignore_fields,
-                                     number_of_laps=self.number_of_laps,
-                                     use_library=self.use_library,
-                                     validate_models=self.validate_models,
-                                     validate_args=self.validate_args,
-                                     print_errors=self.print_errors,
-                                     model_path=next_model_path)
-            if persist_dependencies:
-                data = fixture.get(next_model)
-            else:
-                data = fixture.new(next_model, persist_dependencies=persist_dependencies)
+            ignore_fields = []
+        # 2. It needs a new DynamicFixture to control the cycles and ignored fields.
+        fixture = DynamicFixture(data_fixture=self.data_fixture,
+                                 fill_nullable_fields=self.fill_nullable_fields,
+                                 ignore_fields=ignore_fields,
+                                 fk_min_depth=self.fk_min_depth - 1, # Depth decreased
+                                 validate_models=self.validate_models,
+                                 print_errors=self.print_errors)
+        # 3. Persist it
+        if persist_dependencies:
+            data = fixture.get(next_model)
+        else:
+            data = fixture.new(next_model, persist_dependencies=persist_dependencies)
         return data
 
     def _process_field_with_default_fixture(self, field, model_class, persist_dependencies):
-        "The field has no custom value, so the default behavior of the tool is applied."
-        if field.null and not self.fill_nullable_fields:
-            return None
-        if field_has_default_value(field):
-            if callable(field.default):
-                data = field.default() # datetime default can receive a function: datetime.now
+        '''
+        The field has no custom value (F, C, static, Lessons...), so the default behavior of the tool is applied.
+        - DDF behavior priority for common fields:
+        1. Use `null` if possible (considering the `fill_nullable_fields` settings)
+        2. Use the `default` value
+        3. Use the first option of `choices`
+        - DDF behavior priority for relationship fields:
+        1. Use the `default` value
+        2. Use `null` if possible, or consider the `fk_min_depth` value
+        3. Create a new FK model
+        '''
+        if is_relationship_field(field):
+            if field_has_default_value(field):
+                # datetime default can receive a function: datetime.now
+                data = field.default() if callable(field.default) else field.default
             else:
-                data = field.default
-        elif field_has_choices(field):
-            data = field.flatchoices[0][0] # key of the first choice
-        elif is_relationship_field(field):
-            data = self._process_foreign_key(model_class, field, persist_dependencies)
+                if (not field.null) or self.fk_min_depth > 0:
+                    data = self._process_foreign_key(model_class, field, persist_dependencies)
+                else:
+                    data = None
         else:
-            data = self.data_fixture.generate_data(field)
+            if field_has_default_value(field):
+                # datetime default can receive a function: datetime.now
+                data = field.default() if callable(field.default) else field.default
+            elif field.null and not self.fill_nullable_fields:
+                data = None
+            elif field_has_choices(field):
+                data = field.flatchoices[0][0] # key of the first choice
+            else:
+                data = self.data_fixture.generate_data(field)
         return data
 
     def set_data_for_a_field(self, model_class, __instance, __field, persist_dependencies=True, **kwargs):
@@ -365,89 +403,104 @@ class DynamicFixture(object):
             django_file = data
             if isinstance(django_file, File):
                 setattr(__instance, __field.name, data.name) # set the attribute
-                if django_file.file.mode != 'rb':
+                if hasattr(django_file.file, 'mode') and django_file.file.mode != 'rb':
                     django_file.file.close() # this file may be open in another mode, for example, in a+b
                     opened_file = open(django_file.file.name, 'rb') # to save the file it must be open in rb mode
                     django_file.file = opened_file # we update the reference to the rb mode opened file
-                getattr(__instance, __field.name).save(django_file.name, django_file) # save the file into the file storage system
-                django_file.close()
+
+                # https://github.com/paulocheque/django-dynamic-fixture/issues/10
+                # getattr(__instance, __field.name).save(django_file.name, django_file) # save the file into the file storage system
+                # django_file.close()
+                getattr(__instance, __field.name).save(django_file.name, django_file, save=False)
+
             else: # string (saving just a name in the file, without saving the file to the storage file system
                 setattr(__instance, __field.name, data) # Model.field = data
         else:
             if self.debug_mode:
                 LOGGER.debug('%s.%s = %s' % (get_unique_model_name(model_class), __field.name, data))
-            setattr(__instance, __field.name, data) # Model.field = data
+            try:
+                setattr(__instance, __field.name, data) # Model.field = data
+            except (ValueError, AttributeError) as e:
+                if is_relationship_field(__field):
+                    # Handle AttributeError for compatibility with django-polymorphic
+                    # https://github.com/paulocheque/django-dynamic-fixture/issues/88
+                    field_value = data.id if data and isinstance(e, AttributeError) else data
+                    setattr(__instance, "%s_id" % __field.name, field_value) # Model.field = data
+                else:
+                    six.reraise(*sys.exc_info())
         self.fields_processed.append(__field.name)
 
     def _validate_kwargs(self, model_class, kwargs):
-        "validate all kwargs match Model.fields."
+        '''validate all kwargs match Model.fields.'''
         for field_name in kwargs.keys():
             if field_name in self._DDF_CONFIGS:
                 continue
             if not model_has_the_field(model_class, field_name):
                 raise InvalidConfigurationError('Field "%s" does not exist.' % field_name)
 
-    def _configure_params(self, model_class, shelve, named_shelve, **kwargs):
-        """
+    def _configure_params(self, model_class, ddf_lesson, **kwargs):
+        '''
         1) validate kwargs
         2) load default fixture from DDF library. Store default fixture in DDF library.
         3) Load fixtures defined in F attributes.
-        """
-        if self.validate_args:
-            self._validate_kwargs(model_class, kwargs)
+        '''
+        self._validate_kwargs(model_class, kwargs)
+
+        # load ddf_setup.py of the model application
+        app_name = get_app_name_of_model(model_class)
+        if app_name not in _LOADED_DDF_SETUP_MODULES:
+            full_module_name = '%s.tests.ddf_setup' % app_name
+            try:
+                _LOADED_DDF_SETUP_MODULES.append(app_name)
+                import_module(full_module_name)
+            except ImportError:
+                pass # ignoring if module does not exist
+            except Exception as e:
+                six.reraise(InvalidDDFSetupError, InvalidDDFSetupError(e), sys.exc_info()[2])
+
         library = DDFLibrary.get_instance()
-        if shelve: # shelving before use_library property: do not twist two different configurations (anti-pattern)
-            for field_name in kwargs.keys():
-                if field_name in self._DDF_CONFIGS:
-                    continue
-                field = get_field_by_name_or_raise(model_class, field_name)
-                fixture = kwargs[field_name]
-                if field.unique and not (isinstance(fixture, (DynamicFixture, Copier, DataFixture)) or callable(fixture)):
-                    raise InvalidConfigurationError('It is not possible to store static values for fields with unique=True (%s)' % get_unique_field_name(field))
-            library.add_configuration(model_class, kwargs, name=shelve)
-        if self.use_library:
-            # load ddf_setup.py of the model application
-            app_name = get_app_name_of_model(model_class)
-            if app_name not in _LOADED_DDF_SETUP_MODULES:
-                full_module_name = '%s.tests.ddf_setup' % app_name
-                try:
-                    _LOADED_DDF_SETUP_MODULES.append(app_name)
-                    import_module(full_module_name)
-                except ImportError:
-                    pass # ignoring if module does not exist
-                except Exception as e:
-                    six.reraise(InvalidDDFSetupError, InvalidDDFSetupError(e), sys.exc_info()[2])
-            configuration_default = library.get_configuration(model_class, name=DDFLibrary.DEFAULT_KEY)
-            configuration_custom = library.get_configuration(model_class, name=named_shelve)
-            configuration = {}
-            configuration.update(configuration_default) # always use default configuration
+        configuration = {}
+        # 1. Load the default/global lesson for the model.
+        configuration_default = library.get_configuration(model_class, name=DDFLibrary.DEFAULT_KEY)
+        configuration.update(configuration_default) # always use default configuration
+        # 2. Load a custom lesson for the model.
+        if ddf_lesson:
+            configuration_custom = library.get_configuration(model_class, name=ddf_lesson)
             configuration.update(configuration_custom) # override default configuration
-            configuration.update(kwargs) # override shelved configuration with current configuration
-        else:
-            configuration = kwargs
+        # 3. Load the custom `kwargs` attributes.
+        configuration.update(kwargs) # override the configuration with current configuration
         configuration.update(self.kwargs) # Used by F: kwargs are passed by constructor, not by get.
+
         return configuration
 
-    def new(self, model_class, shelve=False, named_shelve=None, persist_dependencies=True, **kwargs):
-        """
+    def new(self, model_class, ddf_lesson=None, persist_dependencies=True, **kwargs):
+        '''
         Create an instance filled with data without persist it.
         1) validate all kwargs match Model.fields.
         2) validate model is a model.Model class.
         3) Iterate model fields: for each field, fill it with data.
 
-        :shelve: the current configuration will be stored in the DDF library. It can be True or a string (named shelve).
-        :named_shelve: restore configuration saved in DDF library with a name.
+        :ddf_lesson: the lesson that will be used to create the model instance, if exists.
         :persist_dependencies: tell if internal dependencies will be saved in the database or not.
-        """
+        '''
         if self.debug_mode:
             LOGGER.debug('>>> [%s] Generating instance.' % get_unique_model_name(model_class))
-        configuration = self._configure_params(model_class, shelve, named_shelve, **kwargs)
+        configuration = self._configure_params(model_class, ddf_lesson, **kwargs)
         instance = model_class()
         if not is_model_class(instance):
             raise InvalidModelError(get_unique_model_name(model_class))
+
+        try:
+            # https://github.com/paulocheque/django-dynamic-fixture/pull/112
+            from polymorphic import PolymorphicModel
+            is_polymorphic = isinstance(instance, PolymorphicModel)
+        except ImportError:
+            # Django-polymorphic is not installed so the model can't be polymorphic.
+            is_polymorphic = False
         for field in get_fields_from_model(model_class):
-            if is_key_field(field) and 'id' not in configuration: continue
-            if field.name in self.ignore_fields and field.name not in self.kwargs: continue
+            if is_key_field(field) and field.name not in configuration: continue
+            if field.name not in self.kwargs and self._is_ignored_field(field.name): continue
+            if is_polymorphic and (field.name == 'polymorphic_ctype' or field.primary_key): continue
             self.set_data_for_a_field(model_class, instance, field, persist_dependencies=persist_dependencies, **configuration)
         number_of_pending_fields = len(self.pending_fields)
         # For Copier fixtures: dealing with pending fields that need to receive values of another fields.
@@ -458,19 +511,40 @@ class DynamicFixture(object):
             self.set_data_for_a_field(model_class, instance, field, persist_dependencies=persist_dependencies, **configuration)
             i += 1
             if i > 2 * number_of_pending_fields: # dealing with infinite loop too.
-                raise InvalidConfigurationError(get_unique_field_name(field), u'Cyclic dependency of Copiers.')
+                raise InvalidConfigurationError(get_unique_field_name(field), 'Cyclic dependency of Copiers.')
         if self.debug_mode:
             LOGGER.debug('<<< [%s] Instance created.' % get_unique_model_name(model_class))
         return instance
 
+    def _is_ignored_field(self, field_name):
+        '''
+        Return `True` if the given field name should be ignored according to
+        this class's `self.ignored_fields`. Both literal field names and
+        names with wildcard '*' and '?' characters are supported.
+        '''
+        # Do fast check for literal field name first
+        if field_name in self.ignore_fields:
+            return True
+        # If any ignored field names contain wildcards, check them against the
+        # given field name
+        for ignore_spec in self.ignore_fields:
+            if '*' in ignore_spec or '?' in ignore_spec:
+                # Replace wildcard characters with regexp equivalents
+                re_spec = ignore_spec.replace('?', '.').replace('*', '.*')
+                # Update regexp to match entire field name, not just a portion
+                re_spec = r'^%s$' % re_spec
+                if re.match(re_spec, field_name):
+                    return True
+        return False
+
     def _process_many_to_many_field(self, field, manytomany_field, fixture, instance):
-        """
+        '''
         Set ManyToManyField fields with or without 'trough' option.
 
         :field: model field.
         :manytomany_field: ManyRelatedManager of the field.
         :fixture: value passed by user.
-        """
+        '''
         next_model = get_related_model(field)
         if isinstance(fixture, int):
             amount = fixture
@@ -514,14 +588,13 @@ class DynamicFixture(object):
         for field in self.fields_to_disable_auto_now_add:
             enable_auto_now_add(field)
 
-    def get(self, model_class, shelve=False, named_shelve=None, **kwargs):
-        """
+    def get(self, model_class, ddf_lesson=None, **kwargs):
+        '''
         Create an instance with data and persist it.
 
-        :shelve: the current configuration will be stored in the DDF library.
-        :named_shelve: restore configuration saved in DDF library with a name.
-        """
-        instance = self.new(model_class, shelve=shelve, named_shelve=named_shelve, **kwargs)
+        :ddf_lesson: a custom lesson that will be used to create the model object.
+        '''
+        instance = self.new(model_class, ddf_lesson=ddf_lesson, **kwargs)
         if is_model_abstract(model_class):
             raise InvalidModelError(get_unique_model_name(model_class))
         try:
@@ -555,3 +628,17 @@ class DynamicFixture(object):
                 except Exception as e:
                     six.reraise(InvalidManyToManyConfigurationError, InvalidManyToManyConfigurationError(get_unique_field_name(field), e), sys.exc_info()[2])
         return instance
+
+    def teach(self, model_class, ddf_lesson=None, **kwargs):
+        '''
+        @raise an CantOverrideLesson error if the same model/lesson were called twice.
+        '''
+        library = DDFLibrary.get_instance()
+        for field_name in kwargs.keys():
+            if field_name in self._DDF_CONFIGS:
+                continue
+            field = get_field_by_name_or_raise(model_class, field_name)
+            fixture = kwargs[field_name]
+            if field.unique and not (isinstance(fixture, (DynamicFixture, Copier, DataFixture)) or callable(fixture)):
+                raise InvalidConfigurationError('It is not possible to store static values for fields with unique=True (%s). Try using a lambda function instead.' % get_unique_field_name(field))
+        library.add_configuration(model_class, kwargs, name=ddf_lesson)
