@@ -2,16 +2,26 @@
 from datetime import datetime, date, timedelta
 from decimal import Decimal
 import threading
+
 import six
 
-from django_dynamic_fixture.ddf import DataFixture
-from django_dynamic_fixture.django_helper import field_is_unique
+from django.core.exceptions import ImproperlyConfigured
 
 try:
     from django.utils.timezone import now
 except ImportError:
     now = datetime.now
 
+try:
+    from django.contrib.gis.geos import *
+except ImproperlyConfigured:
+    pass  # enviroment without geo libs
+except Exception:
+    pass # Avoid errors like GDALException
+
+from django_dynamic_fixture.fixture_algorithms.default_fixture import BaseDataFixture, GeoDjangoFixtureMixin, PostgresFixtureMixin
+from django_dynamic_fixture.django_helper import field_is_unique
+
 
 class AutoDataFiller(object):
     """
@@ -39,7 +49,7 @@ class AutoDataFiller(object):
         return self.__data_controller_map[key]
 
 
-class SequentialDataFixture(DataFixture):
+class SequentialDataFixture(BaseDataFixture, GeoDjangoFixtureMixin, PostgresFixtureMixin):
 
     def __init__(self):
         super(SequentialDataFixture, self).__init__()
@@ -116,11 +126,12 @@ class SequentialDataFixture(DataFixture):
 
     # FORMATTED STRINGS
     def emailfield_config(self, field, key):
-        return u'a%s@dynamicfixture.com' % self.get_value(field, key)
+        return six.text_type('a%s@dynamicfixture.com') % self.get_value(field, key)
 
     def urlfield_config(self, field, key):
-        return u'http://dynamicfixture%s.com' % self.get_value(field, key)
+        return six.text_type('http://dynamicfixture%s.com') % self.get_value(field, key)
 
+    # Deprecated in Django >= 1.7
     def ipaddressfield_config(self, field, key):
         # TODO: better workaround (this suppose ip field is not unique)
         data = self.get_value(field, key)
@@ -128,10 +139,10 @@ class SequentialDataFixture(DataFixture):
         b = '1'
         c = '1'
         d = data % 256
-        return u'%s.%s.%s.%s' % (a, b, c, str(d))
+        return six.text_type('%s.%s.%s.%s') % (a, b, c, str(d))
 
     def xmlfield_config(self, field, key):
-        return u'<a>%s</a>' % self.get_value(field, key)
+        return six.text_type('<a>%s</a>') % self.get_value(field, key)
 
     # FILES
     def filepathfield_config(self, field, key):
@@ -143,18 +154,6 @@ class SequentialDataFixture(DataFixture):
     def imagefield_config(self, field, key):
         return six.text_type(self.get_value(field, key))
 
-    # BINARY
-    def binaryfield_config(self, field, key):
-        return six.b(self.charfield_config(field, key))
-
-    # GIS/GeoDjango
-    def pointfield_config(self, field, key):
-        from django.contrib.gis.geos import Point
-        val = self.get_value(field, key)
-        rest = val % 90
-        val = rest if (val/90 % 2) else -rest
-        return Point(val, val)
-
 
 class GlobalSequentialDataFixture(SequentialDataFixture):
     def get_value(self, field, key):
